@@ -25,7 +25,7 @@
 #
 #  Created by Dmitry Karasik <dmitry@karasik.eu.org>
 #
-#  $Id: Themes.pm,v 1.4 2004/02/22 18:25:54 dk Exp $
+#  $Id: Themes.pm,v 1.6 2005/10/13 17:22:51 dk Exp $
 
 use strict;
 use Prima;
@@ -46,15 +46,15 @@ load_rc(1) if $load_rc_file || !defined $load_rc_file;
 sub hook
 {
 	my ( $object, $profile, $default) = @_;
-	if ( exists $default->{theme} || exists $profile->{theme}) {
-		my $theme = exists($profile->{theme}) ? $profile->{theme} : $default->{theme};
+	if ( exists $default-> {theme} || exists $profile-> {theme}) {
+		my $theme = exists($profile-> {theme}) ? $profile-> {theme} : $default-> {theme};
 		# execute explicitly selected theme
 		execute( $themes{$theme}, $object, $profile, $default) 
 			if exists $themes{$theme};
 	} else {
 		# execute for all installed themes
-	   	execute( $themes{$_}, $object, $profile, $default) 
-			for grep { $themes{$_}->[INSTALLED] } keys %themes;
+		execute( $themes{$_}, $object, $profile, $default) 
+			for grep { $themes{$_}-> [INSTALLED] } keys %themes;
 	}
 };
 
@@ -71,11 +71,12 @@ sub load_rc
 			next unless defined $r[0] && defined $r[1];
 			$data{$r[1]} = $r[2];
 			eval "use $r[0];";
-         		warn( "** warning: error loading module `$r[0]': $@\n"), next if $@;
-			warn( "** warning: theme `$r[1]' is not defined\n"), next unless loaded($r[1]);
+			warn( "** warning: error loading module `$r[0]': $@\n"), next if $@;
+			warn( "** warning: theme `$r[1]' is not defined\n"), next 
+				unless loaded($r[1]);
 			install($r[1]) if $install;
 		}
-	   	close F;
+		close F;
 	}
 }
 
@@ -86,7 +87,7 @@ sub save_rc
 	my $f = Prima::Utils::path('themes');
 	return 0 unless open F, '>'.$f;
 	for ( keys %themes) {
-		next unless $themes{$_}->[INSTALLED] && $themes{$_}->[MODULE];
+		next unless $themes{$_}-> [INSTALLED] && $themes{$_}-> [MODULE];
 		my $data = defined($data{$_}) ? $data{$_} : '';
 		print F "$themes{$_}->[MODULE],$_,$data\n";
 	}
@@ -99,11 +100,11 @@ sub register
 	my ( $file, $theme, $profile, $merger, $installer) = @_;
 	deregister($_) if $themes{$theme};
 	$themes{$theme} = [ 
-	  0,         # activity flag
-	  $merger,   # merger routine, our own if undef
-	  $profile,  # theme profile
-	  $file,     # theme file
-	  $installer,# installer/uninstaller routine
+		0,         # activity flag
+		$merger,   # merger routine, our own if undef
+		$profile,  # theme profile
+		$file,     # theme file
+		$installer,# installer/uninstaller routine
 	];
 }
 
@@ -117,12 +118,12 @@ sub deregister
 # list registered themes
 sub list { keys %themes }
 # list active themes
-sub list_active { grep { $themes{$_}->[INSTALLED] } keys %themes }
+sub list_active { grep { $themes{$_}-> [INSTALLED] } keys %themes }
 
 # checks if theme is loaded
 sub loaded { defined($_[0]) ? exists $themes{$_[0]} : undef }
 # checks if theme is active
-sub active { (defined($_[0]) && exists $themes{$_[0]}) ? $themes{$_[0]}->[INSTALLED] : undef }
+sub active { (defined($_[0]) && exists $themes{$_[0]}) ? $themes{$_[0]}-> [INSTALLED] : undef }
 
 
 # unistall all themes and select new
@@ -153,11 +154,11 @@ sub install
 {
 	for ( @_) {
 		my $theme = $_;
-		next if !exists $themes{$theme} || $themes{$theme}->[INSTALLED];
-		if ( $themes{$theme}->[INSTALL]) {
-		   $themes{$theme}->[INSTALLED] = $themes{$theme}->[INSTALL]->($theme, 1);
+		next if !exists $themes{$theme} || $themes{$theme}-> [INSTALLED];
+		if ( $themes{$theme}-> [INSTALL]) {
+			$themes{$theme}-> [INSTALLED] = $themes{$theme}-> [INSTALL]-> ($theme, 1);
 		} else {
-		   $themes{$theme}->[INSTALLED] = 1;
+			$themes{$theme}-> [INSTALLED] = 1;
 		}
 	}
 }
@@ -167,9 +168,9 @@ sub uninstall
 {
 	for ( @_) {
 		my $theme = $_;
-		next if !exists $themes{$theme} || !$themes{$theme}->[INSTALLED];
-		$themes{$theme}->[INSTALL]->($theme, 0) if $themes{$theme}->[INSTALL];
-		$themes{$theme}->[INSTALLED] = 0;
+		next if !exists $themes{$theme} || !$themes{$theme}-> [INSTALLED];
+		$themes{$theme}-> [INSTALL]-> ($theme, 0) if $themes{$theme}-> [INSTALL];
+		$themes{$theme}-> [INSTALLED] = 0;
 	}
 }
 
@@ -184,19 +185,19 @@ sub data
 sub merger
 {
 	my ( $object, $profile, $default, $new) = @_;
-	$profile->{$_} = $new->{$_} for keys %$new;
+	$profile-> {$_} = $new-> {$_} for keys %$new;
 }
 
 # applies theme during Object::profile_add
 sub execute
 {
 	my ( $instance, $object, $profile, $default) = @_;
-	my $merger = $instance->[CALLBACK] || \&merger; 
-	my $profiles = $instance->[PROFILE];
+	my $merger = $instance-> [CALLBACK] || \&merger; 
+	my $profiles = $instance-> [PROFILE];
 	return unless $profiles;
 	my $i;
 	for ( $i = 0; $i < @$profiles; $i += 2) {
-		$merger-> ( $object, $profile, $default, $$profiles[$i+1]) if $object->isa($$profiles[$i]);
+		$merger-> ( $object, $profile, $default, $$profiles[$i+1]) if $object-> isa($$profiles[$i]);
 	}
 }
 
@@ -230,7 +231,7 @@ Prima::Themes - object themes management
 
 Provides layer for theme registration in Prima. Themes are loosely grouped
 alternations of default class properties and behavior, by default stored in 
-C<Prima/theme> subdirectory. The theme realization is implemented as interception
+C<Prima/themes> subdirectory. The theme realization is implemented as interception
 of object profile during its creation, inside C<::profile_add>. Various themes
 apply various alterations, one way only - once an object is applied a theme,
 it cannot be neither changed nor revoked thereafter.
@@ -240,31 +241,31 @@ loaded automatically, unless C<$Prima::Themes::load_rc_file> explicitly set to C
 before loading the C<Prima::Themes> module. In effect, any Prima application 
 not aware of themes can be coupled with themes in the rc file by the following:
 
-   perl -MPrima::Themes program
+	perl -MPrima::Themes program
 
 C<Prima::Themes> namespace provides registration and execution functionality.
 C<Prima::Themes::Proxy> is a class for overriding certain methods, for internal
-realization of theme.
+realization of a theme.
 
 For interactive theme selection use F<examples/theme.pl> sample program.
 
 =head1 SYNOPSIS
 
-# register a theme file
-use Prima::Themes qw(color);
-# or
-use Prima::Themes; load('color');
-# list registered themes
-print Prima::Themes::list;
-
-# install a theme
-Prima::Themes::install('cyan');
-# list installed themes
-print Prima::Themes::list_active;
-# create object with another theme while 'cyan' is active
-Class->create( theme => 'yellow');
-# remove a theme
-Prima::Themes::uninstall('cyan');
+	# register a theme file
+	use Prima::Themes qw(color);
+	# or
+	use Prima::Themes; load('color');
+	# list registered themes
+	print Prima::Themes::list;
+	
+	# install a theme
+	Prima::Themes::install('cyan');
+	# list installed themes
+	print Prima::Themes::list_active;
+	# create object with another theme while 'cyan' is active
+	Class->create( theme => 'yellow');
+	# remove a theme
+	Prima::Themes::uninstall('cyan');
 
 =head1 Prima::Themes
 
@@ -273,29 +274,28 @@ Prima::Themes::uninstall('cyan');
 =item load @THEME_MODULES
 
 Load THEME_MODULES from files via C<use> clause, dies on error.
-Can be used instead explicit C<use>.
+Can be used instead of explicit C<use>.
 
 A loaded theme file may register one or more themes.
 
 =item register $FILE, $THEME, $MATCH, $CALLBACK, $INSTALLER
 
-Registers loaded theme. $THEME is unique string identifier.
-$MATCH is an array of pairs, where first item is class string,
-and second is a custom scalar parameter. When a new object is created,
-its class is matched via C<isa> to each given class string,
-and if matched, $CALLBACK routine is called with parameters:
+Registers a previously loaded theme. $THEME is a unique string identifier.
+$MATCH is an array of pairs, where the first item is a class name,
+and the second is an arbitrary scalar parameter. When a new object is created,
+its class is matched via C<isa> to each given class name,
+and if matched, the $CALLBACK routine is called with the following parameters:
 object, default profile, user profile, second item of the matched pair.
 
-If $CALLBACK is C<undef>, default C<merger> routine is called,
-which treats the second items of pairs as hashed of same format as
-default and user profiles.
+If $CALLBACK is C<undef>, the default L<merger> routine is called,
+which treats the second items of the pairs as hashes of the same format as
+the default and user profiles.
 
-The theme is inactive until C<install> is called. If $INSTALLER
-subroutine is passed, it is called during install and uninstall,
-with two parameters, theme name and install flag. When install flag 
-is 1, the theme is about to be installed; the subroutine is expected
-to return a boolean success flag. Otherwise, subroutine return value
-is not used.
+The theme is inactive until C<install> is called. If $INSTALLER subroutine is
+passed, it is called during install and uninstall, with two parameters, the
+name of the theme and boolean install/uninstall flag. When install flag is 1,
+the theme is about to be installed; the subroutine is expected to return a
+boolean success flag. Otherwise, subroutine return value is not used.
 
 $FILE is used to indicate the file in which the theme is stored.
 
@@ -305,7 +305,8 @@ Un-registers $THEME.
 
 =item install @THEMES
 
-Installs loaded THEMES; the installed themes are used to match new objects.
+Installs previosuly loaded and registered loaded THEMES; the installed themes
+are now used to match new objects.
 
 =item uninstall @THEMES
 
@@ -313,28 +314,28 @@ Uninstalls loaded THEMES.
 
 =item list
 
-Returns list of registered themes.
+Returns the list of registered themes.
 
 =item list_active
 
-Returns list of installed themes.
+Returns the list of installed themes.
 
 =item loaded $THEME
 
-Return 1 if theme is registered, 0 otherwise.
+Return 1 if $THEME is registered, 0 otherwise.
 
 =item active $THEME
 
-Return 1 if theme is installed, 0 otherwise.
+Return 1 if $THEME is installed, 0 otherwise.
 
 =item select @THEMES
 
-Uninstalls all currently installed themes, and installs THEMES.
+Uninstalls all currently installed themes, and installs THEMES instead.
 
 =item merger $OBJECT, $PROFILE_DEFAULT, $PROFILE_USER, $PROFILE_THEME
 
-Default profile merging routine, merges $PROFILE_THEME into $PROFILE_USER,
-based in keys found in $PROFILE_DEFAULT.
+Default profile merging routine, merges $PROFILE_THEME into $PROFILE_USER
+by keys from $PROFILE_DEFAULT.
 
 =item load_rc [ $INSTALL = 1 ]
 
@@ -352,27 +353,27 @@ returns success flag. If success flag is 0, C<$!> contains the error.
 
 An instance of C<Prima::Themes::Proxy>, created as
 
-  Prima::Themes::Proxy-> new( $OBJECT)
+Prima::Themes::Proxy-> new( $OBJECT)
 
-is a non-functional wrapper for any Perl object $OBJECT. Any methods of $OBJECT
-class, except C<AUTOLOAD>, C<DESTROY>, and C<new>, are forwarded to $OBJECT
+is a non-functional wrapper for any Perl object $OBJECT. All methods of $OBJECT,
+except C<AUTOLOAD>, C<DESTROY>, and C<new>, are forwarded to $OBJECT
 itself transparently. The class can be used, for example, to deny all
 changes to C<lineWidth> inside object's painting routine:
 
-   package ConstLineWidth;
-   use vars qw(@ISA);
-   @ISA = qw(Prima::Themes::Proxy);
+	package ConstLineWidth;
+	use vars qw(@ISA);
+	@ISA = qw(Prima::Themes::Proxy);
 
-   sub lineWidth { 1 } # line width is always 1 now!
+	sub lineWidth { 1 } # line width is always 1 now!
 
-   Prima::Themes::register( '~/lib/constlinewidth.pm', 'constlinewidth', 
-   [ 'Prima::Widget' => {
-      onPaint => sub {
-         my ( $object, $canvas) = @_;
-         $object-> on_paint( ConstLineWidth-> new( $canvas));
-      },
-   } ]
-   );
+	Prima::Themes::register( '~/lib/constlinewidth.pm', 'constlinewidth', 
+		[ 'Prima::Widget' => {
+			onPaint => sub {
+				my ( $object, $canvas) = @_;
+				$object-> on_paint( ConstLineWidth-> new( $canvas));
+			},
+		} ]
+	);
 
 =head1 AUTHOR
 
