@@ -24,7 +24,7 @@
  * SUCH DAMAGE.
  */
 /* Created by Dmitry Karasik <dk@plab.ku.dk> */
-/* $Id: codec_png.c,v 1.6 2002/09/13 10:46:59 dk Exp $ */
+/* $Id: codec_png.c,v 1.9 2004/11/25 15:11:56 dk Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <generic/config.h>
@@ -221,7 +221,7 @@ init( PImgCodecInfo * info, void * param)
 
 
 #define outc(x){ strncpy( fi-> errbuf, x, 256); return false;}
-#define outcm(dd){ snprintf( fi-> errbuf, 256, "No enough memory (%d bytes)", (int)dd); return false;}
+#define outcm(dd){ snprintf( fi-> errbuf, 256, "No enough memory (%d bytes)", (int)(dd)); return false;}
 
 #define ALPHA_OPT_BLEND 2
 #define ALPHA_OPT_SPLIT 1
@@ -639,9 +639,10 @@ load( PImgCodec instance, PImgLoadFileInstance fi)
    if ( icon) {
       if ( alpha_image) {
           int i, sz = PIcon( fi-> object)-> maskSize;
-          char * mask = PIcon( fi-> object)-> mask;
+          Byte * mask = PIcon( fi-> object)-> mask;
           RGBColor dummy[2];
-          ic_graybyte_mono_ictNone( alpha_image, PIcon( fi-> object)-> mask, dummy, imbpp1);
+          int palSize = 0;
+          ic_byte_mono_ictNone( alpha_image, PIcon( fi-> object)-> mask, dummy, imbpp1, &palSize, false);
           for ( i = 0; i < sz; i++, mask++) *mask = ~*mask;
           PIcon( fi-> object)-> autoMasking = amNone;
       } else if ( trns_n) {
@@ -673,10 +674,11 @@ READ_END:
       char * name, * pf;
       int ct, i;
       png_uint_32 pl, py;
+      png_int_32 pli, pyi;
       png_textp tx;
       double scx, scy;
 
-      (void)tx; (void)py; (void)pl; (void)i; (void)ct;
+      (void)tx; (void)py; (void)pl; (void)pyi; (void)pli; (void)i; (void)ct;
       (void)pf; (void)name; (void)scx; (void)scy;
 
       png_read_end(l-> png_ptr, l-> info_ptr);
@@ -716,9 +718,9 @@ READ_END:
 #endif      
 
 #ifdef PNG_oFFs_SUPPORTED      
-      if ( png_get_oFFs( l-> png_ptr, l-> info_ptr, &pl, &py, &i)) {
-         pset_i( offset_x, pl);
-         pset_i( offset_y, py);
+      if ( png_get_oFFs( l-> png_ptr, l-> info_ptr, &pli, &pyi, &i)) {
+         pset_i( offset_x, pli);
+         pset_i( offset_y, pyi);
          pset_c( offset_dimension, ( i == PNG_OFFSET_PIXEL) ? "pixel" : "micrometer");
       }
 #endif      
